@@ -1,8 +1,8 @@
 import os, glob
-from parse_all import *
+from .parse_all import *
 
 __copyright__    = 'Copyright (C) 2022 BoronSpoon'
-__version__      = '1.0.5'
+__version__      = '1.0.6'
 __license__      = 'MIT License'
 __author__       = 'boronspoon'
 __author_email__ = 'rayanticlimactic@gmail.com'
